<?php

namespace Asadi\Result\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Result\Interfaces\ResultRepositoryInterface;
use Asadi\Result\Repositories\Presenter\ResultItemTransformer;

/**
 * Pubic API controller class.
 */
class ResultPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Result\Interfaces\ResultRepositoryInterface $result
     *
     * @return type
     */
    public function __construct(ResultRepositoryInterface $result)
    {
        $this->repository = $result;
        parent::__construct();
    }

    /**
     * Show result's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $results = $this->repository
            ->setPresenter('\\Asadi\\Result\\Repositories\\Presenter\\ResultListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $results['code'] = 2000;
        return response()->json($results)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show result.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $result = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($result)) {
            $result         = $this->itemPresenter($module, new ResultItemTransformer);
            $result['code'] = 2001;
            return response()->json($result)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
