<?php

namespace Asadi\Result\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Asadi\Result\Http\Requests\ResultRequest;
use Asadi\Result\Interfaces\ResultRepositoryInterface;
use Asadi\Result\Models\Result;

/**
 * User API controller class.
 */
class ResultUserController extends BaseController
{
    /**
     * Initialize result controller.
     *
     * @param type ResultRepositoryInterface $result
     *
     * @return type
     */
    public function __construct(ResultRepositoryInterface $result)
    {
        $this->repository = $result;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Result\Repositories\Criteria\ResultUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of result.
     *
     * @return json
     */
    public function index(ResultRequest $request)
    {
        $results  = $this->repository
            ->setPresenter('\\Asadi\\Result\\Repositories\\Presenter\\ResultListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $results['code'] = 2000;
        return response()->json($results) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display result.
     *
     * @param Request $request
     * @param Model   Result
     *
     * @return Json
     */
    public function show(ResultRequest $request, Result $result)
    {

        if ($result->exists) {
            $result         = $result->presenter();
            $result['code'] = 2001;
            return response()->json($result)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new result.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(ResultRequest $request, Result $result)
    {
        $result         = $result->presenter();
        $result['code'] = 2002;
        return response()->json($result)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new result.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(ResultRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $result          = $this->repository->create($attributes);
            $result          = $result->presenter();
            $result['code']  = 2004;

            return response()->json($result)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show result for editing.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return json
     */
    public function edit(ResultRequest $request, Result $result)
    {
        if ($result->exists) {
            $result         = $result->presenter();
            $result['code'] = 2003;
            return response()-> json($result)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the result.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return json
     */
    public function update(ResultRequest $request, Result $result)
    {
        try {

            $attributes = $request->all();

            $result->update($attributes);
            $result         = $result->presenter();
            $result['code'] = 2005;

            return response()->json($result)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the result.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return json
     */
    public function destroy(ResultRequest $request, Result $result)
    {

        try {

            $t = $result->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('result::result.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
