<?php

namespace Asadi\Result\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Asadi\Result\Http\Requests\ResultRequest;
use Asadi\Result\Interfaces\ResultRepositoryInterface;
use Asadi\Result\Models\Result;

/**
 * Admin web controller class.
 */
class ResultAdminController extends BaseController
{
    // use ResultWorkflow;
    /**
     * Initialize result controller.
     *
     * @param type ResultRepositoryInterface $result
     *
     * @return type
     */
    public function __construct(ResultRepositoryInterface $result)
    {
        $this->repository = $result;
        parent::__construct();
    }

    /**
     * Display a list of result.
     *
     * @return Response
     */
    public function index(ResultRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('result::result.names').' :: ');
        return $this->theme->of('result::admin.result.index')->render();
    }

    /**
     * Display a list of result.
     *
     * @return Response
     */
    public function getJson(ResultRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $results  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Asadi\\Result\\Repositories\\Presenter\\ResultListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $results['recordsTotal']    = $results['meta']['pagination']['total'];
        $results['recordsFiltered'] = $results['meta']['pagination']['total'];
        $results['request']         = $request->all();
        return response()->json($results, 200);

    }

    /**
     * Display result.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return Response
     */
    public function show(ResultRequest $request, Result $result)
    {
        if (!$result->exists) {
            return response()->view('result::admin.result.new', compact('result'));
        }

        Form::populate($result);
        return response()->view('result::admin.result.show', compact('result'));
    }

    /**
     * Show the form for creating a new result.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ResultRequest $request)
    {

        $result = $this->repository->newInstance([]);

        Form::populate($result);

        return response()->view('result::admin.result.create', compact('result'));

    }

    /**
     * Create new result.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ResultRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $result          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('result::result.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/result/result/'.$result->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show result for editing.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return Response
     */
    public function edit(ResultRequest $request, Result $result)
    {
        Form::populate($result);
        return  response()->view('result::admin.result.edit', compact('result'));
    }

    /**
     * Update the result.
     *
     * @param Request $request
     * @param Model   $result
     *
     * @return Response
     */
    public function update(ResultRequest $request, Result $result)
    {
        try {

            $attributes = $request->all();

            $result->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('result::result.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/result/result/'.$result->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/result/result/'.$result->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the result.
     *
     * @param Model   $result
     *
     * @return Response
     */
    public function destroy(ResultRequest $request, Result $result)
    {

        try {

            $t = $result->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('result::result.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/result/result/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/result/result/'.$result->getRouteKey()),
            ], 400);
        }
    }

}
