<?php

namespace Asadi\Result\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Asadi\Result\Http\Requests\ResultRequest;
use Asadi\Result\Interfaces\ResultRepositoryInterface;
use Asadi\Result\Models\Result;

class ResultUserController extends BaseController
{
    /**
     * Initialize result controller.
     *
     * @param type ResultRepositoryInterface $result
     *
     * @return type
     */
    public function __construct(ResultRepositoryInterface $result)
    {
        $this->repository = $result;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Result\Repositories\Criteria\ResultUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ResultRequest $request)
    {
        $results = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('result::result.names'));

        return $this->theme->of('result::user.result.index', compact('results'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Result $result
     *
     * @return Response
     */
    public function show(ResultRequest $request, Result $result)
    {
        Form::populate($result);

        return $this->theme->of('result::user.result.show', compact('result'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ResultRequest $request)
    {

        $result = $this->repository->newInstance([]);
        Form::populate($result);

        $this->theme->prependTitle(trans('result::result.names'));
        return $this->theme->of('result::user.result.create', compact('result'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ResultRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $result = $this->repository->create($attributes);

            return redirect(trans_url('/user/result/result'))
                -> with('message', trans('messages.success.created', ['Module' => trans('result::result.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Result $result
     *
     * @return Response
     */
    public function edit(ResultRequest $request, Result $result)
    {

        Form::populate($result);
        $this->theme->prependTitle(trans('result::result.names'));

        return $this->theme->of('result::user.result.edit', compact('result'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Result $result
     *
     * @return Response
     */
    public function update(ResultRequest $request, Result $result)
    {
        try {
            $this->repository->update($request->all(), $result->getRouteKey());

            return redirect(trans_url('/user/result/result'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('result::result.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ResultRequest $request, Result $result)
    {
        try {
            $this->repository->delete($result->getRouteKey());
            return redirect(trans_url('/user/result/result'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('result::result.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
