<?php

namespace Asadi\Result\Policies;

use App\User;
use Asadi\Result\Models\Result;

class ResultPolicy
{

    /**
     * Determine if the given user can view the result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function view(User $user, Result $result)
    {
        if ($user->canDo('result.result.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $result->user_id;
    }

    /**
     * Determine if the given user can create a result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('result.result.create');
    }

    /**
     * Determine if the given user can update the given result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function update(User $user, Result $result)
    {
        if ($user->canDo('result.result.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $result->user_id;
    }

    /**
     * Determine if the given user can delete the given result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function destroy(User $user, Result $result)
    {
        if ($user->canDo('result.result.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $result->user_id;
    }

    /**
     * Determine if the given user can verify the given result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function verify(User $user, Result $result)
    {
        if ($user->canDo('result.result.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('result.result.verify') 
        && $user->is('manager')
        && $result->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given result.
     *
     * @param User $user
     * @param Result $result
     *
     * @return bool
     */
    public function approve(User $user, Result $result)
    {
        if ($user->canDo('result.result.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
