<?php

namespace Asadi\Result\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Result\Models\Result;

class ResultAction
{
    /**
     * Perform the complete action.
     *
     * @param Result $result
     *
     * @return Result
     */
    public function complete(Result $result)
    {
        try {
            $result->status = 'complete';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Result $result
     *
     * @return Result
     */public function verify(Result $result)
    {
        try {
            $result->status = 'verify';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Result $result
     *
     * @return Result
     */public function approve(Result $result)
    {
        try {
            $result->status = 'approve';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Result $result
     *
     * @return Result
     */public function publish(Result $result)
    {
        try {
            $result->status = 'publish';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Result $result
     *
     * @return Result
     */
    public function archive(Result $result)
    {
        try {
            $result->status = 'archive';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Result $result
     *
     * @return Result
     */
    public function unpublish(Result $result)
    {
        try {
            $result->status = 'unpublish';
            return $result->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
